==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/OdbiorOdpadow.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class OdbiorOdpadow extends GenericDPSObject {
    /**
     * ODBIOR_ODPADOW.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * ODBIOR_ODPADOW.DATA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date data;

    /**
     * ODBIOR_ODPADOW.ODBIERAJACY_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long odbierajacyId;

    /**
     * ODBIOR_ODPADOW.RODZAJ_MATERIALU_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long rodzajMaterialuId;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return ODBIOR_ODPADOW.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * ODBIOR_ODPADOW.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return ODBIOR_ODPADOW.DATA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getData() {
        return data;
    }

    /**
     * ODBIOR_ODPADOW.DATA
     *
     * @param data
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setData(Date data) {
        this.data = data;
    }

    /**
     * @return ODBIOR_ODPADOW.ODBIERAJACY_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getOdbierajacyId() {
        return odbierajacyId;
    }

    /**
     * ODBIOR_ODPADOW.ODBIERAJACY_ID
     *
     * @param odbierajacyId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOdbierajacyId(Long odbierajacyId) {
        this.odbierajacyId = odbierajacyId;
    }

    /**
     * @return ODBIOR_ODPADOW.RODZAJ_MATERIALU_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getRodzajMaterialuId() {
        return rodzajMaterialuId;
    }

    /**
     * ODBIOR_ODPADOW.RODZAJ_MATERIALU_ID
     *
     * @param rodzajMaterialuId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setRodzajMaterialuId(Long rodzajMaterialuId) {
        this.rodzajMaterialuId = rodzajMaterialuId;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        OdbiorOdpadow other = (OdbiorOdpadow) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getData() == null ? other.getData() == null : this.getData().equals(other.getData()))
            && (this.getOdbierajacyId() == null ? other.getOdbierajacyId() == null : this.getOdbierajacyId().equals(other.getOdbierajacyId()))
            && (this.getRodzajMaterialuId() == null ? other.getRodzajMaterialuId() == null : this.getRodzajMaterialuId().equals(other.getRodzajMaterialuId()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getData() == null) ? 0 : getData().hashCode());
        result = prime * result + ((getOdbierajacyId() == null) ? 0 : getOdbierajacyId().hashCode());
        result = prime * result + ((getRodzajMaterialuId() == null) ? 0 : getRodzajMaterialuId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", data=").append(data);
        sb.append(", odbierajacyId=").append(odbierajacyId);
        sb.append(", rodzajMaterialuId=").append(rodzajMaterialuId);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/OdbiorOdpadow.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class OdbiorOdpadow extends GenericDPSObject {
    /**
     * ODBIOR_ODPADOW.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * ODBIOR_ODPADOW.DATA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date data;

    /**
     * ODBIOR_ODPADOW.ODBIERAJACY_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long odbierajacyId;

    /**
     * ODBIOR_ODPADOW.RODZAJ_MATERIALU_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long rodzajMaterialuId;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return ODBIOR_ODPADOW.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * ODBIOR_ODPADOW.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return ODBIOR_ODPADOW.DATA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getData() {
        return data;
    }

    /**
     * ODBIOR_ODPADOW.DATA
     *
     * @param data
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setData(Date data) {
        this.data = data;
    }

    /**
     * @return ODBIOR_ODPADOW.ODBIERAJACY_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getOdbierajacyId() {
        return odbierajacyId;
    }

    /**
     * ODBIOR_ODPADOW.ODBIERAJACY_ID
     *
     * @param odbierajacyId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOdbierajacyId(Long odbierajacyId) {
        this.odbierajacyId = odbierajacyId;
    }

    /**
     * @return ODBIOR_ODPADOW.RODZAJ_MATERIALU_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getRodzajMaterialuId() {
        return rodzajMaterialuId;
    }

    /**
     * ODBIOR_ODPADOW.RODZAJ_MATERIALU_ID
     *
     * @param rodzajMaterialuId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setRodzajMaterialuId(Long rodzajMaterialuId) {
        this.rodzajMaterialuId = rodzajMaterialuId;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        OdbiorOdpadow other = (OdbiorOdpadow) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getData() == null ? other.getData() == null : this.getData().equals(other.getData()))
            && (this.getOdbierajacyId() == null ? other.getOdbierajacyId() == null : this.getOdbierajacyId().equals(other.getOdbierajacyId()))
            && (this.getRodzajMaterialuId() == null ? other.getRodzajMaterialuId() == null : this.getRodzajMaterialuId().equals(other.getRodzajMaterialuId()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getData() == null) ? 0 : getData().hashCode());
        result = prime * result + ((getOdbierajacyId() == null) ? 0 : getOdbierajacyId().hashCode());
        result = prime * result + ((getRodzajMaterialuId() == null) ? 0 : getRodzajMaterialuId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", data=").append(data);
        sb.append(", odbierajacyId=").append(odbierajacyId);
        sb.append(", rodzajMaterialuId=").append(rodzajMaterialuId);
        sb.append("]");
        return sb.toString();
    }
}
